@@ -1,4 +1,5 @@
 import logging
+import traceback
 
 from opentelemetry.instrumentation.transformers.config import Config
 
@@ -29,7 +30,11 @@ def dont_throw(func):
         try:
             return func(*args, **kwargs)
         except Exception as e:
-            logger.warning("Failed to execute %s, error: %s", func.__name__, str(e))
+            logger.debug(
+                "OpenLLMetry failed to trace in %s, error: %s",
+                func.__name__,
+                traceback.format_exc(),
+            )
             if Config.exception_logger:
                 Config.exception_logger(e)
 
